diff --git a/MP-TAB/MP-TAB.csproj b/MP-TAB/MP-TAB.csproj
index 4b88e2e0..df6b24a4 100644
--- a/MP-TAB/MP-TAB.csproj
+++ b/MP-TAB/MP-TAB.csproj
@@ -419,7 +419,12 @@
-
+
+ Always
+
+
+ Always
+
diff --git a/MP-TAB/WebUserControls/BaseUserControl.cs b/MP-TAB/WebUserControls/BaseUserControl.cs
index 33b150c4..398efde8 100644
--- a/MP-TAB/WebUserControls/BaseUserControl.cs
+++ b/MP-TAB/WebUserControls/BaseUserControl.cs
@@ -315,12 +315,18 @@ namespace MoonProTablet.WebUserControls
{
url = "Steamware.png";
}
- // verifico esistenza macchina...
- answ = $"./images/macchine/{url}";
+ // verifico esistenza macchina SMALL...
+ answ = $"./images/macchine/small/{url}";
string fullPath = Server.MapPath(answ);
if (!File.Exists(fullPath))
{
- // metto default Steamware
+ // se non ci fosse cerco immagine fullsize
+ answ = $"./images/macchine/{url}";
+ fullPath = Server.MapPath(answ);
+ }
+ // altrimenti metto default Steamware
+ if (!File.Exists(fullPath))
+ {
answ = "./images/macchine/Steamware.png";
}
return answ;
diff --git a/MP-TAB/images/macchine/small/Steamware.png b/MP-TAB/images/macchine/small/Steamware.png
new file mode 100644
index 00000000..5d4a75b1
Binary files /dev/null and b/MP-TAB/images/macchine/small/Steamware.png differ